@@ -1,6 +1,6 @@
 ;;; helm-core-pkg.el --- define helm-core for package.el
 
-(define-package "helm-core" "1.9.9"
+(define-package "helm-core" "2.0"
   "Development files for Helm"
   '((emacs "24.3")
     (async "1.9"))
