@@ -59,6 +59,7 @@
           ;; properly (empty buffer) when called from lisp
           ;; with 'no-fetch (emacs-25 WA).
           (package-show-package-list)
+        (when helm--force-updating-p (message "Refreshing packages list..."))  
         (list-packages helm-el-package--initialized-p))
       (setq helm-el-package--initialized-p t)
       (message nil))
@@ -68,9 +69,9 @@
         (setq helm-el-package--tabulated-list tabulated-list-entries)
         (buffer-string)))
     (setq helm-el-package--upgrades (helm-el-package-menu--find-upgrades))
-    (if helm-force-updating-p
+    (if helm--force-updating-p
         (if helm-el-package--upgrades
-            (message "%d package(s) can be upgraded, Refreshing packages list done"
+            (message "Refreshing packages list done, [%d] package(s) to upgrade"
                      (length helm-el-package--upgrades))
           (message "Refreshing packages list done, no upgrades available"))
       (setq helm-el-package--show-only (if helm-el-package--upgrades
@@ -256,7 +257,11 @@
            for name = (if (fboundp 'package-desc-name)
                           (and id (package-desc-name id))
                           (car id))
-           for installed-p = (assq name package-alist)
+           for desc = (package-desc-status id)
+           for built-in-p = (and (package-built-in-p name)
+                                 (not (member desc '("available" "new"
+                                                     "installed" "dependency"))))
+           for installed-p = (member desc '("installed" "dependency"))
            for upgrade-p = (assq name helm-el-package--upgrades)
            for user-installed-p = (and (boundp 'package-selected-packages)
                                        (memq name package-selected-packages))
@@ -267,15 +272,25 @@
                  2 (+ (length (symbol-name name)) 2)
                  'face 'font-lock-variable-name-face c))
            for cand = (cons c (car (split-string c)))
-           when (or (and upgrade-p
+           when (or (and built-in-p
+                         (eq helm-el-package--show-only 'built-in))
+                    (and upgrade-p
                          (eq helm-el-package--show-only 'upgrade))
                     (and installed-p
                          (eq helm-el-package--show-only 'installed))
                     (and (not installed-p)
-                         (eq helm-el-package--show-only 'uninstalled)) 
+                         (not built-in-p)
+                         (eq helm-el-package--show-only 'uninstalled))
                     (eq helm-el-package--show-only 'all))
            collect cand))
 
+(defun helm-el-package-show-built-in ()
+  (interactive)
+  (with-helm-alive-p
+    (setq helm-el-package--show-only 'built-in)
+    (helm-update)))
+(put 'helm-el-package-show-built-in 'helm-only t)
+
 (defun helm-el-package-show-upgrade ()
   (interactive)
   (with-helm-alive-p
@@ -310,6 +325,7 @@
     (define-key map (kbd "M-I")   'helm-el-package-show-installed)
     (define-key map (kbd "M-O")   'helm-el-package-show-uninstalled)
     (define-key map (kbd "M-U")   'helm-el-package-show-upgrade)
+    (define-key map (kbd "M-B")   'helm-el-package-show-built-in)
     (define-key map (kbd "M-A")   'helm-el-package-show-all)
     (define-key map (kbd "C-c i") 'helm-el-run-package-install)
     (define-key map (kbd "C-c r") 'helm-el-run-package-reinstall)
@@ -333,14 +349,18 @@
                        ("Visit homepage" . helm-el-package-visit-homepage)))))
 
 (defun helm-el-package--action-transformer (actions candidate)
-  (let* ((pkg-desc (get-text-property
-                    0 'tabulated-list-id candidate))
+  (let* ((pkg-desc (get-text-property 0 'tabulated-list-id candidate))
+         (status (package-desc-status pkg-desc))
          (pkg-name (package-desc-name pkg-desc))
+         (built-in (and (package-built-in-p pkg-name)
+                        (not (member status '("available" "new"
+                                              "installed" "dependency")))))
          (acts (if helm-el-package--upgrades
                    (append actions '(("Upgrade all packages"
                                       . helm-el-package-upgrade-all-action)))
                    actions)))
-    (cond ((and (package-installed-p pkg-name)
+    (cond (built-in '(("Describe package" . helm-el-package-describe)))
+          ((and (package-installed-p pkg-name)
                 (cdr (assq pkg-name helm-el-package--upgrades)))
            (append '(("Upgrade package(s)" . helm-el-package-upgrade)
                      ("Uninstall package(s)" . helm-el-package-uninstall)) acts))
