@@ -404,28 +404,30 @@ from its directory."
   "Sort predicate function for helm candidates.
 Args S1 and S2 can be single or \(display . real\) candidates,
 that is sorting is done against real value of candidate."
-  (let* ((pattern (regexp-quote helm-pattern))
-         (reg1  (concat "\\_<" pattern "\\_>"))
-         (reg2  (concat "\\_<" pattern))
+  (let* ((qpattern (regexp-quote helm-pattern))
+         (reg1  (concat "\\_<" qpattern "\\_>"))
+         (reg2  (concat "\\_<" qpattern))
          (reg3  helm-pattern)
-         (split (split-string pattern))
+         (split (split-string helm-pattern))
          (str1  (if (consp s1) (cdr s1) s1))
          (str2  (if (consp s2) (cdr s2) s2))
          (score (lambda (str r1 r2 r3 lst)
-                    (+ (if (string-match (concat "\\`" pattern) str) 1 0)
+                    (+ (if (string-match (concat "\\`" qpattern) str) 1 0)
                        (cond ((string-match r1 str) 5)
-                             ((and (string-match " " pattern)
-                                   (string-match (concat "\\_<" (car lst)) str)
+                             ((and (string-match " " qpattern)
+                                   (string-match
+                                    (concat "\\_<" (regexp-quote (car lst))) str)
                                    (cl-loop for r in (cdr lst)
                                             always (string-match r str))) 4)
-                             ((and (string-match " " pattern)
-                                   (cl-loop for r in lst always (string-match r str))) 3)
+                             ((and (string-match " " qpattern)
+                                   (cl-loop for r in lst
+                                            always (string-match r str))) 3)
                              ((string-match r2 str) 2)
                              ((string-match r3 str) 1)
                              (t 0)))))
          (sc1 (funcall score str1 reg1 reg2 reg3 split))
          (sc2 (funcall score str2 reg1 reg2 reg3 split)))
-    (cond ((or (zerop (string-width pattern))
+    (cond ((or (zerop (string-width qpattern))
                (and (zerop sc1) (zerop sc2)))
            (string-lessp str1 str2))
           ((= sc1 sc2)
@@ -695,10 +697,10 @@ If STRING is non--nil return instead a space separated string."
   (require 'popup)
   (if helm-popup-tip-mode
       (progn
-        (add-hook 'helm-update-hook 'helm-show-help-echo) ; Needed for async sources.
+        (add-hook 'helm-after-update-hook 'helm-show-help-echo) ; Needed for async sources.
         (add-hook 'helm-move-selection-after-hook 'helm-show-help-echo)
         (add-hook 'helm-cleanup-hook 'helm-cancel-help-echo-timer))
-      (remove-hook 'helm-update-hook 'helm-show-help-echo)
+      (remove-hook 'helm-after-update-hook 'helm-show-help-echo)
       (remove-hook 'helm-move-selection-after-hook 'helm-show-help-echo)
       (remove-hook 'helm-cleanup-hook 'helm-cancel-help-echo-timer)))
 
